@@ -8,8 +8,8 @@ import (
 
 const DNSServerEnv = "DDNS_GO_DNS_SERVER"
 
-// customDNSResolver 当 DNSServerEnv 值不为空时，使用 Go 内置 DNS 解析器来解析其 DNS 服务器。
-func customDNSResolver() *net.Resolver {
+// CustomDNSResolver 当 DNSServerEnv 值不为空时，使用 Go 内置 DNS 解析器来解析其 DNS 服务器。
+func CustomDNSResolver() *net.Resolver {
 	s := os.Getenv(DNSServerEnv)
 	if s != "" {
 		return &net.Resolver{
@@ -19,5 +19,6 @@ func customDNSResolver() *net.Resolver {
 			},
 		}
 	}
+
 	return &net.Resolver{}
 }
